NT_AddSchema

Function NT_AddSchema 

pub unsafe extern "C" fn NT_AddSchema(
    inst: NT_Inst,
    name: *const WPI_String,
    type_: *const WPI_String,
    schema: *const u8,
    schema_size: usize,
)
Registers a data schema. Data schemas provide information for how a certain data type string can be decoded. The type string of a data schema indicates the type of the schema itself (e.g. “protobuf” for protobuf schemas, “struct” for struct schemas, etc). In NetworkTables, schemas are published just like normal topics, with the name being generated from the provided name: “/.schema/”. Duplicate calls to this function with the same name are silently ignored.

Parameters

  • inst: Instance handle.
  • name: Name (the string passed as the data type for topics using this schema).
  • type: Type of schema (e.g. “protobuf”, “struct”, etc).
  • schema: Schema data.
  • schema_size: Size of schema data.